 ;======================== header ===============================================
;+
; NAME:
;   cactus_cmes
; PURPOSE:
;   Wrapper for standalone SSW-friendly CACTus development 
;
; CATEGORY:
;   cactus ver 4.00 (paperA&A-version, May 2004)
; CALLING SEQUENCE:
;   (meant to be used in batchmode)
; INPUTS:
;   
; 
; KEYWORD PARAMETERS:
;   /logfile: to print diagnostics to a logfile 
; 			0 =default=stdout=screen
; 			1 = single file, cactus_log.txt
;			2 = multiple files for each module, eg incube_log.txt etc
; OUTPUTS:
;   flags/velmap
;   flags/catalo
; COMMON BLOCKS: 
;   none
; SIDE EFFECTS: 
;   unknown
; RESTRICTIONS:
;   unknown
; PROCEDURE:
;
; CALLS:
;
; TO DO:
;
; MODIFICATION HISTORY:
;   2005/04/11, ver 1.00, Gareth Lawrence - original SSW-friendly implementation of standalone CACTus software
;   2006/05/05	GRL		Implement widget for date selection; cast logging routines properly
;-
;======================== end header ===========================================
PRO cactus_cmes , logfile = logfile, box_plots = box_plots, startdate, enddate

COMMON CACTUS_ENVS, cactusdir,cactusbin,cactusvar,cactusread,cactusout,cactuswrite,cactuslog
COMMON CACTUS_JULTIME, julstart
COMMON CACTUSINDEX, cactusindex						
COMMON CACTUS_FOV, npixelr, npixela, npixelx, npixely, km_per_cactusmap_pix,  $
					    minradius_c2, maxradius_c2, minradius_c3, maxradius_c3 					   
					    
  cactusdir =	getenv('CACTUSDIR')
  cactusbin =	getenv('CACTUSBIN')
  cactusvar =	getenv('CACTUSVAR')

  cactusread  = getenv('CACTUSREAD')
  cactusout =	   getenv('CACTUSOUT')
  cactuswrite = getenv('CACTUSWRITE')
  cactuslog =	   getenv('CACTUSLOG')

   myname   ='cactus'

if not ( keyword_set(logfile) ) then logfile = 0

   CASE (logfile) OF
	0 : log=-1
	1 :  begin
;print,'logfile = 1, all output will be written to cactus_log.txt ... '
openw, log, cactuslog+'cactus_log.txt' , /get_lun , /append 
end
	2 :  openw, log, cactuslog+ myname+'_log.txt', /get_lun , /append
    ENDCASE

printf,log,' '
printf,log,' Welcome to CACTus, the Computer Aided CME Tracking software package! '
printf,log,' This software is provided by the SIDC, Royal Observatory of Belgium. '
printf,log,' '
printf,log,' Please wait while CACTus searches for CMEs within the dates specified. '
printf,log,' '

if logfile ne 0 then begin
print,' '
print,' Welcome to CACTus, the Computer Aided CME Tracking software package! '
print,' This software is provided by the SIDC, Royal Observatory of Belgium. '
print,' '
print,' Please wait while CACTus searches for CMEs within the dates specified. '
print,' '
case (logfile) of
	1: begin
		print,' Run-time details will be collected in a single cactus_log.txt file '
	     	print,' with the date/time at end of run appended '
	     	print, '  '
	    end
	2: begin
		printf,log,' Please refer to the individual *_log.txt files for full run-time details '
		printf,log,'  '
		print, ' Please refer to the individual *_log.txt files for full run-time details '
		print, '  '
	     end
endcase
endif


;; Below now obsolete since introduction of date widget
;startdate=''
;enddate=''
;read,'Please enter start date in 6-digit YYMMDD format: ', startdate
;read,'Please enter end date in 6-digit YYMMDD format: ', enddate

if not (keyword_set(startdate) and keyword_set(enddate)) then begin
cactus_date, cac_dates
  if (datatype(cac_dates) eq 'UND') then begin
	printf,log,'No dates, aborting CACTUS...'
   IF keyword_set(logfile) THEN BEGIN
      close, log
      free_lun, log
   ENDIF

	return
  endif else begin
	startdate = cac_dates.beg_date
	enddate = cac_dates.end_date
  endelse
endif else begin
	printf,log,'  !!WARNING!!: CACTus will CRASH if the dates have not been specified in YYMMDD format! ... '
endelse


restore,cactusvar+'fov.sav'
restore,cactusvar+'julstart.sav'
restore,cactusvar+'cactusindex.sav'

   IF keyword_set(logfile) THEN BEGIN
      close, log
      free_lun, log
   ENDIF


; stop

; if keyword_set(logfile) then logfile=logfile else logfile=0
  					    
cactus_incube, logfile=logfile, startdate, enddate, $
			   c2_ar, c2_xy, c2_ind, c3_ar, c3_xy, c3_ind
   
			   
reldev, logfile=logfile, c2_ar, c2_xy, c2_ind, c3_ar, c3_xy, c3_ind, $
			   datacube, index, slices  
			   

velmap, logfile=logfile, slices, index, $ 
			   velocity_settings, vectors, tvanglecube

; if not keyword_set(box_plots) then box_plots = 0

cactus_cat, logfile=logfile, box_plots=box_plots, tvanglecube, velocity_settings, vectors, index, slices

; print,log
; stop

date_time = strmid(!stime,0,11)+'_'+strmid(!stime,12,2)+strmid(!stime,15,2)
oldlogfile = cactuslog+'cactus_log.txt'
newlogfile = cactuslog+'cactus_log_'+date_time+'.txt'

   CASE (logfile) OF
	0 : log=-1
	1 : begin
		openw, log, cactuslog+'cactus_log.txt' , /get_lun , /append 
		print, '  '
		print,        ' Run-time details have been written to: '
		print,  '   ' +  newlogfile
	     end
	2 : begin
		openw, log, cactuslog+ myname+'_log.txt', /get_lun , /append
		printf,log,  ' '
		printf,log,' Run-time details have been written to the *_log.txt files in '
		printf,log,  '   ' + cactuslog
		print,  ' '
		print,' Run-time details have been written to the *_log.txt files in '
		print,  '   ' + cactuslog
	     end
    ENDCASE

printf,log,' '
printf,log,' Thank you for using CACTus, the Computer Aided CME Tracking software package. '
printf,log,' Remember to check the latest real-time CME monitoring output at '
printf,log,' '
printf,log,' http://www.sidc.be/cactus/out/latestCMEs.html '
printf,log,' '

;spawn,'mv '+oldlogfile+' '+newlogfile

if logfile ne 0 then begin
print,' '
print,' Thank you for using CACTus, the Computer Aided CME Tracking software. '
print,' Remember to check the latest real-time CME monitoring output at '
print,' '
print,' http://www.sidc.be/cactus/out/latestCMEs.html '
print,' '
endif

   IF keyword_set(logfile) THEN BEGIN
      close, log
      free_lun, log
   ENDIF

if logfile eq 1 then spawn,'mv '+oldlogfile+' '+newlogfile

end



